import React from 'react';
import { motion } from 'framer-motion';
import { ChevronDown, ChevronUp } from 'lucide-react';

const Accordion = ({ title, children, isOpen, onToggle }) => {
    return (
        <div className="rounded-2xl mb-4 overflow-hidden">
            <button onClick={onToggle} className="flex justify-between items-center w-full p-4 text-left bg-bg-default focus:outline-none">
                <div className="flex justify-start items-center">
                    <div className='flex justify-center items-center h-12 w-12 me-3 bg-primary rounded-full'>
                        <p className='text-text-white text-lg font-bold'>P</p>
                    </div>

                    <div>
                        <p className="text-[.9rem] font-bold text-text-primary mb-1">{title}</p>
                        <p className="text-[.8rem] font-normal text-text-primary">+55 11 99999-9999</p>
                    </div>
                </div>
                {isOpen ? <ChevronUp className='text-text-primary' /> : <ChevronDown className='text-text-primary' />}
            </button>

            <motion.div
                initial={{ height: 0, opacity: 0 }}
                animate={{ height: isOpen ? 'auto' : 0, opacity: isOpen ? 1 : 0 }}
                transition={{ duration: 0.3 }}
                className="overflow-hidden"
            >
                <div className="p-4 text-gray-700 border-t border-border bg-bg-default">
                    {children}
                </div>
            </motion.div>
        </div>
    );
};

export default Accordion;
